from typing import Optional, Union
import datetime


def ulid(timestamp: Optional[Union[datetime.datetime, float]] = None) -> str:
    """
    Generate a ULID.

    :param timestamp: The timestamp to use. Defaults to the current time.
    :return: A ULID.
    """
    pass


def decode_timestamp(ulid: str) -> float:
    """
    Return timestamp of ULID in `float`.

    :param ulid: A ULID.
    :return: timestamp
    """
    pass


def decode_datetime(ulid: str) -> float:
    """
    Return timestamp of ULID in `datetime.datetime`.
    Timestamp can cause overflow, so if it's too large, please use `decode_timestamp` instead.

    :param ulid: A ULID.
    :return: timestamp in `datetime.datetime`
    """
    pass



from setuptools import setup, Extension

fast_ulid__title__ = "fast-ulid"
fast_ulid__description__ = "Easy to use ULID generator"
fast_ulid__url__ = "https://github.com/nagataaaas/fast-ulid"
fast_ulid__version_info__ = ("0", "2", "0")
fast_ulid__version__ = ".".join(fast_ulid__version_info__)
fast_ulid__author__ = "Yamato Nagata"
fast_ulid__author_email__ = "chickenwingswillfly@gmail.com"
fast_ulid__maintainer__ = "Yamato Nagata"
fast_ulid__license__ = "MIT"
fast_ulid__copyright__ = "(c) 2022 by Yamato Nagata"

setup(name=fast_ulid__title__,
      version=fast_ulid__version__,
      url=fast_ulid__url__,
      license=fast_ulid__license__,
      author=fast_ulid__author__,
      author_email=fast_ulid__author_email__,
      description=fast_ulid__description__,
      long_description=__doc__,
      long_description_content_type="text/markdown",
      platforms="any",
      classifiers=[
          "Development Status :: 4 - Beta",
          "Environment :: Other Environment",
          "Intended Audience :: Developers",
          "License :: OSI Approved :: MIT License",
          "Operating System :: OS Independent",
          "Programming Language :: Python :: 3",
          "Programming Language :: Python",
          "Topic :: Software Development :: Libraries :: Python Modules"
      ],
      packages=["fast_ulid"],
      package_data={
          'fast_ulid': ["py.typed", "*.pyi"]
      },
      ext_modules=[
          Extension('fast_ulid', ['./fast_ulid/ULID.cpp'], language='c++'),
      ])
